turbopack_runtime_import_map

Function turbopack_runtime_import_map 

pub fn turbopack_runtime_import_map() -> Vc<ImportMap>
Returns an ImportMap containing:

  • The @vercel/turbopack-ecmascript-runtime/* wildcard alias pointing to the embedded runtime filesystem.
  • All built-in @turbopack/* module aliases (e.g. @turbopack/base64).

This import map is injected automatically by [ModuleAssetContext::resolve_options] so that every Turbopack-processed module can resolve these paths without per-consumer configuration.

As more parts of the turbopack runtime are extracted into importable modules they should be added here.